==> maven_3.5.4.orig.tar.xz: maven-maven-3.5.4/maven-artifact/src/test/java/org/apache/maven/artifact/handler/ArtifactHandlerMock.java <==
package org.apache.maven.artifact.handler;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

public class ArtifactHandlerMock
    implements ArtifactHandler
{

    private String extension, directory, classifier, packaging, language;

    private boolean includesDependencies, addedToClasspath;

    public void setExtension( String extension )
    {
        this.extension = extension;
    }

    public String getExtension()
    {
        return extension;
    }

    public void setDirectory( String directory )
    {
        this.directory = directory;
    }

    public String getDirectory()
    {
        return directory;
    }

    public void setClassifier( String classifier )
    {
        this.classifier = classifier;
    }

    public String getClassifier()
    {
        return classifier;
    }

    public void setPackaging( String packaging )
    {
        this.packaging = packaging;
    }

    public String getPackaging()
    {
        return packaging;
    }

    public void setIncludesDependencies( boolean includesDependencies )
    {
        this.includesDependencies = includesDependencies;
    }

    public boolean isIncludesDependencies()
    {
        return includesDependencies;
    }

    public void setLanguage( String language )
    {
        this.language = language;
    }

    public String getLanguage()
    {
        return language;
    }

    public void setAddedToClasspath( boolean addedToClasspath )
    {
        this.addedToClasspath = addedToClasspath;
    }

    public boolean isAddedToClasspath()
    {
        return addedToClasspath;
    }

}

==> maven_3.9.12.orig.tar.xz: maven-maven-3.9.12/maven-artifact/src/test/java/org/apache/maven/artifact/handler/ArtifactHandlerMock.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.artifact.handler;

public class ArtifactHandlerMock implements ArtifactHandler {

    private String extension, directory, classifier, packaging, language;
    private boolean includesDependencies, addedToClasspath;

    public void setExtension(String extension) {
        this.extension = extension;
    }

    public String getExtension() {
        return extension;
    }

    public void setDirectory(String directory) {
        this.directory = directory;
    }

    public String getDirectory() {
        return directory;
    }

    public void setClassifier(String classifier) {
        this.classifier = classifier;
    }

    public String getClassifier() {
        return classifier;
    }

    public void setPackaging(String packaging) {
        this.packaging = packaging;
    }

    public String getPackaging() {
        return packaging;
    }

    public void setIncludesDependencies(boolean includesDependencies) {
        this.includesDependencies = includesDependencies;
    }

    public boolean isIncludesDependencies() {
        return includesDependencies;
    }

    public void setLanguage(String language) {
        this.language = language;
    }

    public String getLanguage() {
        return language;
    }

    public void setAddedToClasspath(boolean addedToClasspath) {
        this.addedToClasspath = addedToClasspath;
    }

    public boolean isAddedToClasspath() {
        return addedToClasspath;
    }
}
